@@ -27,15 +27,16 @@
 #include <gtk/gtkmessagedialog.h>
 #include <libgnome/gnome-i18n.h>
 #include <libebook/e-book.h>
+#include <libedataserverui/e-passwords.h>
 
-#include "e-util/e-passwords.h"
-
+#include "widgets/misc/e-error.h"
 #include "addressbook.h"
 
 #define d(x)
 
 static void addressbook_authenticate (EBook *book, gboolean previous_failure,
 				      ESource *source, EBookCallback cb, gpointer closure);
+static void auth_required_cb (EBook *book, gpointer data);
 
 typedef struct {
 	EBookCallback cb;
@@ -56,7 +57,7 @@ free_load_source_data (LoadSourceData *data)
 in uri*/
 
 static gchar*
-remove_parameters_from_uri (gchar *uri)
+remove_parameters_from_uri (const gchar *uri)
 {
   gchar **components;
   gchar *new_uri = NULL;
@@ -82,40 +83,47 @@ load_source_auth_cb (EBook *book, EBookStatus status, gpointer closure)
 
 		/* the user clicked cancel in the password dialog */
 		if (status == E_BOOK_ERROR_CANCELLED) {
-				
+
 			if (e_book_check_static_capability (book, "anon-access")) {
-			
-			GtkWidget *dialog;
 
-			/* XXX "LDAP" has to be removed from the folowing message
-			   so that it wil valid for other servers which provide 
-			   anonymous access*/
+				GtkWidget *dialog;
 
-			dialog = gtk_message_dialog_new (NULL,
-							 0,
-							 GTK_MESSAGE_WARNING,
-							 GTK_BUTTONS_OK,
-							 _("Accessing LDAP Server anonymously"));
-			g_signal_connect (dialog, "response", G_CALLBACK(gtk_widget_destroy), NULL);
-			gtk_widget_show (dialog);
-			data->cb (book, E_BOOK_ERROR_OK, data->closure);
+				/* XXX "LDAP" has to be removed from the folowing message
+				   so that it wil valid for other servers which provide 
+				   anonymous access*/
+
+				dialog = gtk_message_dialog_new (NULL,
+						0,
+						GTK_MESSAGE_WARNING,
+						GTK_BUTTONS_OK,
+						_("Accessing LDAP Server anonymously"));
+				g_signal_connect (dialog, "response", G_CALLBACK(gtk_widget_destroy), NULL);
+				gtk_widget_show (dialog);
+				if (data->cb)
+					data->cb (book, E_BOOK_ERROR_OK, data->closure);
+				free_load_source_data (data);
+				return;
+			}
+		} else if (status == E_BOOK_ERROR_INVALID_SERVER_VERSION) {
+			e_error_run (NULL, "addressbook:server-version", NULL);
+			status = E_BOOK_ERROR_OK;
+			if (data->cb)
+				data->cb (book, status, data->closure);
 			free_load_source_data (data);
 			return;
-			}
-		}
-		else {
-			gchar *uri = e_source_get_uri (data->source);
+
+		} else {
+			const gchar *uri = e_book_get_uri (book);
 			gchar *stripped_uri = remove_parameters_from_uri (uri);
 			const gchar *auth_domain = e_source_get_property (data->source, "auth-domain");
-		        const gchar *component_name;
-			
+			const gchar *component_name;
+
 			component_name = auth_domain ? auth_domain : "Addressbook";
-			
+
 			e_passwords_forget_password (component_name, stripped_uri);
 			addressbook_authenticate (book, TRUE, data->source, load_source_auth_cb, closure);
-			
+
 			g_free (stripped_uri);
-			g_free (uri);
 			return;
 		}
 	}
@@ -153,13 +161,12 @@ addressbook_authenticate (EBook *book, gboolean previous_failure, ESource *sourc
 	char *pass_dup = NULL;
 	const gchar *auth;
 	const gchar *user;
-	gchar *uri = e_source_get_uri (source);
+	const gchar *uri = e_book_get_uri (book);
         gchar *stripped_uri = remove_parameters_from_uri (uri);
 	const gchar *auth_domain = e_source_get_property (source, "auth-domain");
 	const gchar *component_name;
 			
 	component_name = auth_domain ? auth_domain : "Addressbook";
-	g_free (uri);
 	uri = stripped_uri;
 
 	password = e_passwords_get_password (component_name, uri);
@@ -177,6 +184,7 @@ addressbook_authenticate (EBook *book, gboolean previous_failure, ESource *sourc
 
 	if (!password) {
 		char *prompt;
+		char *password_prompt;
 		gboolean remember;
 		char *failed_auth;
 		guint32 flags = E_PASSWORDS_REMEMBER_FOREVER|E_PASSWORDS_SECRET|E_PASSWORDS_ONLINE;
@@ -189,8 +197,11 @@ addressbook_authenticate (EBook *book, gboolean previous_failure, ESource *sourc
 			failed_auth = "";
 		}
 
-		prompt = g_strdup_printf (_("%sEnter password for %s (user %s)"),
-					  failed_auth, e_source_peek_name (source), user);
+		password_prompt = g_strdup_printf (_("Enter password for %s (user %s)"),
+					   e_source_peek_name (source), user);
+
+		prompt = g_strconcat (failed_auth, password_prompt, NULL);
+		g_free (password_prompt);
 
 		remember = get_remember_password (source);
 		pass_dup = e_passwords_ask_password (prompt, component_name, uri, prompt,
@@ -210,8 +221,7 @@ addressbook_authenticate (EBook *book, gboolean previous_failure, ESource *sourc
 	}
 	else {
 		/* they hit cancel */
-	
-			cb (book, E_BOOK_ERROR_CANCELLED, closure);
+		cb (book, E_BOOK_ERROR_CANCELLED, closure);
 	}
 
 	g_free (uri);
