@@ -26,12 +26,12 @@
 #include <string.h>
 #include <bonobo/bonobo-main.h>
 #include <libedataserver/e-url.h>
+#include <libedataserverui/e-passwords.h>
 #include <libecal/e-cal.h>
 #include "alarm-notify.h"
 #include "alarm-queue.h"
 #include "config-data.h"
 #include "common/authentication.h"
-#include "e-util/e-passwords.h"
 
 
 /* Private part of the AlarmNotify structure */
@@ -57,8 +57,8 @@ static BonoboObjectClass *parent_class;
 
 BONOBO_TYPE_FUNC_FULL(AlarmNotify, GNOME_Evolution_Calendar_AlarmNotify, BONOBO_TYPE_OBJECT, alarm_notify)
 
-     /* Class initialization function for the alarm notify service */
-     static void
+/* Class initialization function for the alarm notify service */
+static void
 alarm_notify_class_init (AlarmNotifyClass *klass)
 {
 	GObjectClass *object_class;
@@ -261,7 +261,9 @@ alarm_notify_finalize (GObject *object)
 		g_hash_table_foreach (priv->uri_client_hash[i], dequeue_client, NULL);
 		g_hash_table_destroy (priv->uri_client_hash[i]);
 	}
-	
+
+	alarm_queue_done ();
+
 	g_mutex_free (priv->mutex);
 	g_free (priv);
 
@@ -303,6 +305,9 @@ cal_opened_cb (ECal *client, ECalendarStatus status, gpointer user_data)
 	else {
 		g_hash_table_remove (priv->uri_client_hash[e_cal_get_source_type (client)],
 				     e_cal_get_uri (client));
+		g_signal_handlers_disconnect_matched (G_OBJECT (client), G_SIGNAL_MATCH_DATA,
+						      0, 0, NULL, NULL, an);
+		g_object_unref (client);
 	}
 }
 
