@@ -52,6 +52,7 @@
 #include "config-data.h"
 #include "util.h"
 #include "e-util/e-popup.h"
+#include "widgets/misc/e-error.h"
 
 
 
@@ -683,7 +684,7 @@ edit_component (ECal *client, ECalComponent *comp)
 						      0, NULL, &ev);
 
 	if (BONOBO_EX (&ev)) {
-		g_message (G_STRLOC ": Could not activate the component editor factory");
+		e_error_run (NULL, "editor-error", bonobo_exception_get_text (&ev));
 		CORBA_exception_free (&ev);
 		return;
 	}
@@ -700,7 +701,7 @@ edit_component (ECal *client, ECalComponent *comp)
 	GNOME_Evolution_Calendar_CompEditorFactory_editExisting (factory, uri, (char *) uid, corba_type, &ev);
 
 	if (BONOBO_EX (&ev))
-		g_message (G_STRLOC ": Exception while editing the component");
+		e_error_run (NULL, "editor-error", bonobo_exception_get_text (&ev));
 
 	CORBA_exception_free (&ev);
 
@@ -763,7 +764,7 @@ notify_dialog_cb (AlarmNotifyResult result, int snooze_mins, gpointer data)
 	case ALARM_NOTIFY_SNOOZE:
 		create_snooze (tray_data->cqa, tray_data->alarm_id, snooze_mins);
 		tray_data->cqa = NULL;
-		return;
+		break;
 
 	case ALARM_NOTIFY_EDIT:
 		edit_component (tray_data->client, tray_data->comp);
@@ -1036,6 +1037,7 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	if (!config_data_get_notify_with_tray ()) {
 		tray_data->blink_id = -1;
 		open_alarm_dialog (tray_data);
+		gtk_window_stick (GTK_WINDOW (tray_data->alarm_dialog));
 	} else {
 		tray_data->blink_id = g_timeout_add (500, tray_icon_blink_cb, tray_data);
 		gtk_widget_show (tray_icon);
