@@ -129,6 +129,7 @@ EventEditor *
 event_editor_construct (EventEditor *ee, ECal *client)
 {
 	EventEditorPrivate *priv;
+	gboolean read_only = FALSE;
 
 	priv = ee->priv;
 
@@ -147,6 +148,10 @@ event_editor_construct (EventEditor *ee, ECal *client)
 	comp_editor_append_page (COMP_EDITOR (ee),
 				 COMP_EDITOR_PAGE (priv->recur_page),
 				 _("Recurrence"));
+
+	if (!e_cal_is_read_only (client, &read_only, NULL))
+			read_only = TRUE;
+	comp_editor_sensitize_attachment_bar (COMP_EDITOR (ee), !read_only);
 	
 	if (priv->is_meeting) {
 		if (e_cal_get_static_capability (client, CAL_STATIC_CAPABILITY_REQ_SEND_OPTIONS))
@@ -217,7 +222,7 @@ event_editor_edit_comp (CompEditor *editor, ECalComponent *comp)
 	e_meeting_store_remove_all_attendees (priv->model);
 
 	/* Set up the attendees */
-	if (attendees == NULL && !priv->is_meeting) {
+	if (attendees == NULL) {
 		if (priv->meet_page)
 			comp_editor_remove_page (editor, COMP_EDITOR_PAGE (priv->meet_page));
 		if (priv->sched_page)
@@ -332,12 +337,30 @@ event_editor_finalize (GObject *object)
 	ee = EVENT_EDITOR (object);
 	priv = ee->priv;
 
-	g_object_unref (priv->event_page);
-	g_object_unref (priv->recur_page);
-	g_object_unref (priv->meet_page);
-	g_object_unref (priv->sched_page);
+	if (priv->event_page) {
+ 		g_object_unref (priv->event_page);
+		priv->event_page = NULL;
+	}
+	
+	if (priv->recur_page) {
+		g_object_unref (priv->recur_page);
+		priv->recur_page = NULL;
+	}
 
-	g_object_unref (priv->model);
+	if (priv->meet_page) {
+		g_object_unref (priv->meet_page);
+		priv->meet_page = NULL;
+	}
+
+	if (priv->sched_page) {
+		g_object_unref (priv->sched_page);
+		priv->sched_page = NULL;
+	}
+
+	if (priv->model) {
+		g_object_unref (priv->model);
+		priv->model = NULL;
+	}
 
 	g_free (priv);
 
@@ -372,6 +395,7 @@ show_meeting (EventEditor *ee)
 	priv = ee->priv;
 
 	
+	event_page_set_meeting (priv->event_page, TRUE);
 	if (!priv->meeting_shown) {
 		comp_editor_append_page (COMP_EDITOR (ee),
 					 COMP_EDITOR_PAGE (priv->sched_page),
@@ -381,7 +405,7 @@ show_meeting (EventEditor *ee)
 					 _("Invitations"));
 		priv->meeting_shown = TRUE;
 
- 		comp_editor_set_changed (COMP_EDITOR (ee), priv->meeting_shown);
+ 		comp_editor_set_changed (COMP_EDITOR (ee), FALSE);
 		comp_editor_set_needs_send (COMP_EDITOR (ee), priv->meeting_shown);
 	}
 	
