@@ -175,6 +175,7 @@ struct _GnomeCalendarPrivate {
 	   'dates-shown-changed' signal.*/
 	time_t visible_start;
 	time_t visible_end;
+	gboolean updating;
 };
 
 /* Signal IDs */
@@ -715,9 +716,13 @@ update_query (GnomeCalendar *gcal)
 
 	priv = gcal->priv;
 
+	if (priv->updating == TRUE) {
+		return;
+	}
 	e_calendar_view_set_status_message (E_CALENDAR_VIEW (priv->week_view), _("Updating query"));
 	e_calendar_item_clear_marks (priv->date_navigator->calitem);
 
+	priv->updating = TRUE;
 	/* free the previous queries */
 	for (l = priv->dn_queries; l != NULL; l = l->next) {
 		old_query = l->data;
@@ -737,6 +742,7 @@ update_query (GnomeCalendar *gcal)
 	real_sexp = adjust_e_cal_view_sexp (gcal, priv->sexp);
 	if (!real_sexp) {
 		e_calendar_view_set_status_message (E_CALENDAR_VIEW (priv->week_view), NULL);
+		priv->updating = FALSE;
 		return; /* No time range is set, so don't start a query */
 	}
 
@@ -768,6 +774,7 @@ update_query (GnomeCalendar *gcal)
 	}
 
 	/* free memory */
+	priv->updating = FALSE;
 	g_free (real_sexp);
 	e_calendar_view_set_status_message (E_CALENDAR_VIEW (priv->week_view), NULL);
 	update_todo_view (gcal);
@@ -1412,6 +1419,7 @@ gnome_calendar_init (GnomeCalendar *gcal)
 
 	priv->visible_start = -1;
 	priv->visible_end = -1;
+	priv->updating = FALSE;
 }
 
 static void
@@ -2169,6 +2177,7 @@ client_cal_opened_cb (ECal *ecal, ECalendarStatus status, GnomeCalendar *gcal)
 	GnomeCalendarPrivate *priv;
 	ECalSourceType source_type;
 	ESource *source;
+	ECalLoadState state;
 	char *msg;
 	int i;
 
@@ -2176,6 +2185,7 @@ client_cal_opened_cb (ECal *ecal, ECalendarStatus status, GnomeCalendar *gcal)
 
 	source_type = e_cal_get_source_type (ecal);
 	source = e_cal_get_source (ecal);
+	state = e_cal_get_load_state (ecal);
 
 	switch (source_type) {
 	case E_CAL_SOURCE_TYPE_EVENT:
@@ -2189,9 +2199,12 @@ client_cal_opened_cb (ECal *ecal, ECalendarStatus status, GnomeCalendar *gcal)
 	}
 	switch (status) {
 	case E_CALENDAR_STATUS_OK:
+		g_message ("********* the state  in ok is %d \n", state);
 		break;
 	case E_CALENDAR_STATUS_BUSY:
-		e_cal_open_async (ecal, FALSE);
+		g_message ("********* the state is %d \n", state);
+		if (state == E_CAL_LOAD_NOT_LOADED)
+			e_cal_open_async (ecal, FALSE);
 		return;
 	case E_CALENDAR_STATUS_INVALID_SERVER_VERSION:
 		e_error_run (NULL, "calendar:server-version", NULL);
@@ -2260,12 +2273,14 @@ default_client_cal_opened_cb (ECal *ecal, ECalendarStatus status, GnomeCalendar
 	GnomeCalendarPrivate *priv;
 	ECalSourceType source_type;
 	ESource *source;
+	ECalLoadState state;
 	int i;
 
 	priv = gcal->priv;
 
 	source_type = e_cal_get_source_type (ecal);
 	source = e_cal_get_source (ecal);
+	state = e_cal_get_load_state (ecal);
 
 	switch (source_type) {
 	case E_CAL_SOURCE_TYPE_EVENT:
@@ -2282,7 +2297,9 @@ default_client_cal_opened_cb (ECal *ecal, ECalendarStatus status, GnomeCalendar
 	case E_CALENDAR_STATUS_OK:
 		break;
 	case E_CALENDAR_STATUS_BUSY:
-		e_cal_open_async (ecal, FALSE);
+		g_message ("********* the state is %d \n", state);
+		if (state == E_CAL_LOAD_NOT_LOADED)
+			e_cal_open_async (ecal, FALSE);
 		return;
 	case E_CALENDAR_STATUS_INVALID_SERVER_VERSION :
 		e_error_run (NULL, "calendar:server-version", NULL);
@@ -3259,6 +3276,9 @@ gnome_calendar_purge (GnomeCalendar *gcal, time_t older_than)
 			if (remove)
 				e_cal_remove_object (client, icalcomponent_get_uid (m->data), NULL);
 		}
+
+		g_list_foreach (objects, (GFunc) icalcomponent_free, NULL);
+		g_list_free (objects);
 	}
 
 	e_calendar_view_set_status_message (E_CALENDAR_VIEW (priv->week_view), NULL);
