@@ -562,7 +562,7 @@ efh_object_requested(GtkHTML *html, GtkHTMLEmbedded *eb, EMFormatHTML *efh)
 		res = pobject->func(efh, eb, pobject);
 		e_dlist_addhead(&efh->pending_object_list, (EDListNode *)pobject);
 	} else {
-		printf("HTML Includes reference to unknown object '%s'\n", eb->classid);
+		d(printf("HTML Includes reference to unknown object '%s'\n", eb->classid));
 	}
 
 	return res;
@@ -1484,7 +1484,6 @@ efh_format_address (GString *out, struct _camel_header_address *a)
 static void
 efh_format_header(EMFormat *emf, CamelStream *stream, CamelMedium *part, struct _camel_header_raw *header, guint32 flags, const char *charset)
 {
-	CamelMimeMessage *msg = (CamelMimeMessage *)part;
 	EMFormatHTML *efh = (EMFormatHTML *)emf;
 	char *name, *value = NULL, *p;
 	const char *label, *txt;
@@ -1640,6 +1639,8 @@ efh_format_headers(EMFormatHTML *efh, CamelStream *stream, CamelMedium *part)
 			header = header->next;
 		}
 	} else {
+		int mailer_shown = FALSE;
+		
 		while (h->next) {
 			int mailer;
 
@@ -1647,13 +1648,14 @@ efh_format_headers(EMFormatHTML *efh, CamelStream *stream, CamelMedium *part)
 			mailer = !g_ascii_strcasecmp (h->name, "X-Evolution-Mailer");
 			
 			while (header) {
-				if (mailer && (!g_ascii_strcasecmp (header->name, "X-Mailer") ||
+				if (!mailer_shown && mailer && (!g_ascii_strcasecmp (header->name, "X-Mailer") ||
 					       !g_ascii_strcasecmp (header->name, "User-Agent") ||
 					       !g_ascii_strcasecmp (header->name, "X-Newsreader"))) {
 					struct _camel_header_raw xmailer;
 					
 					xmailer.name = "X-Evolution-Mailer";
 					xmailer.value = header->value;
+					mailer_shown = TRUE;
 					
 					efh_format_header (emf, stream, part, &xmailer, h->flags, charset);
 					if (strstr(header->value, "Evolution"))
