@@ -36,10 +36,13 @@
 #include <libedataserver/e-source.h>
 #include <libedataserverui/e-source-selector.h>
 #include <libecal/e-cal.h>
+#include "calendar/common/authentication.h"
 #include <calendar/gui/e-cal-popup.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <string.h>
 
+#include "widgets/misc/e-error.h"
+
 #include "format-handler.h"
 
 typedef struct _CsvConfig CsvConfig;
@@ -320,6 +323,7 @@ do_save_calendar_csv (FormatHandler *handler, EPlugin *ep, ECalPopupTargetSource
 	CsvConfig *config = NULL;
 	CsvPluginData *d = handler->data;
 	const gchar *tmp = NULL;
+	gboolean doit = TRUE;
 
 	if (!dest_uri)
 		return;
@@ -327,7 +331,7 @@ do_save_calendar_csv (FormatHandler *handler, EPlugin *ep, ECalPopupTargetSource
 	primary_source = e_source_selector_peek_primary_selection (target->selector);
 
 	/* open source client */
-	source_client = e_cal_new (primary_source, type);
+	source_client = auth_new_cal_from_source (primary_source, type);
 	if (!e_cal_open (source_client, TRUE, &error)) {
 		display_error_message (gtk_widget_get_toplevel (GTK_WIDGET (target->selector)), error);
 		g_object_unref (source_client);
@@ -346,13 +350,21 @@ do_save_calendar_csv (FormatHandler *handler, EPlugin *ep, ECalPopupTargetSource
 	config->header = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (d->header_check));
 
 	uri = gnome_vfs_uri_new (dest_uri);
-	result = gnome_vfs_open_uri (&handle, uri, GNOME_VFS_OPEN_WRITE);
-	if (result != GNOME_VFS_OK) {
-		gnome_vfs_create (&handle, dest_uri, GNOME_VFS_OPEN_WRITE, TRUE, GNOME_VFS_PERM_USER_ALL);
+
+	result = gnome_vfs_open_uri (&handle, uri, GNOME_VFS_OPEN_READ);
+	if (result == GNOME_VFS_OK)
+		doit = e_error_run(gtk_widget_get_toplevel (GTK_WIDGET (target->selector)),
+			 E_ERROR_ASK_FILE_EXISTS_OVERWRITE, dest_uri, NULL) == GTK_RESPONSE_OK;
+
+	if (doit) {
 		result = gnome_vfs_open_uri (&handle, uri, GNOME_VFS_OPEN_WRITE);
+		if (result != GNOME_VFS_OK) {
+			gnome_vfs_create (&handle, dest_uri, GNOME_VFS_OPEN_WRITE, TRUE, GNOME_VFS_PERM_USER_ALL);
+			result = gnome_vfs_open_uri (&handle, uri, GNOME_VFS_OPEN_WRITE);
+		} 
 	}
 
-	if (result == GNOME_VFS_OK && e_cal_get_object_list_as_comp (source_client, "#t", &objects, NULL)) {
+	if (result == GNOME_VFS_OK && doit && e_cal_get_object_list_as_comp (source_client, "#t", &objects, NULL)) {
 
 		if (config->header) {
 			line = g_string_new ("");
